<?php
define( 'DB_PRODUCTS_STOCK', $config['dir_db'].$config['language'].'_products_stock.php' );

/**
* Return product stock quantity
* @return int
* @param int  $iProduct
*/
function throwProductStock( $iProduct ){
  global $oFF;
  if( !is_file( DB_PRODUCTS_STOCK ) )
    return null;
  $aData = $oFF->throwData( DB_PRODUCTS_STOCK, $iProduct );

  if( isset( $aData ) && is_array( $aData ) )
    return $aData[1];
  else
    return null;
} // end function throwProductStock

/**
* Return products stock quantity
* @return void
* @param array
*/
function throwProductsStock( ){
  global $oFF;
  if( !is_file( DB_PRODUCTS_STOCK ) )
    return null;
  return $oFF->throwFileArraySmall( DB_PRODUCTS_STOCK, null, 0, 1 );
} // end function throwProductsStock

/**
* Save stock quantity for product
* @return void
* @param int  $iStock
* @param int  $iProduct
*/
function saveStock( $iStock, $iProduct ){
  global $oFF;
  if( !is_file( DB_PRODUCTS_STOCK ) )
    return null;

  if( isset( $iProduct ) && is_numeric( $iProduct ) ){
    $oFF->deleteInFile( DB_PRODUCTS_STOCK, $iProduct, 0 );
  }
  else{
    $iProduct = throwLastId( ) + 1;
  }

  if( is_numeric( $iStock ) ){
    $oFF->setRow( Array( $iProduct, $iStock ) );
    $oFF->addToFile( DB_PRODUCTS_STOCK ); 
  }
} // end function saveStock

/**
* Return product quantity in basket
* @return array
* @param int  $iElement
*/
function throwOrderElementQuantity( $iElement ){
  global $oFF;
  $aData = $oFF->throwData( DB_ORDERS_PRODUCTS, $iElement );

  if( isset( $aData ) && is_array( $aData ) )
    return $aData;
  else
    return null;
} // end function throwOrderElementQuantity

/**
* Return products quantity in basket
* @return int
* @param int  $iElement
*/
function throwOrderProductQuantity( $iProduct, $iOrder ){
  global $oFF;
  $aData = $oFF->throwFileArrayClause( DB_ORDERS_PRODUCTS, null, 1, $iOrder );
  $iCount= count( $aData );
  for( $i = 0; $i < $iCount; $i++ ){
    if( $aData[$i][2] == $iProduct )
      return $aData[$i][3];
  } // end for
} // end function throwOrderProductQuantity

/**
* Change products stock
* @return void
* @param int  $iOrder
*/
function changeProductsStock( $iOrder ){
  $aStock   = throwProductsStock( );
  $aBasket  = dbListBasket( $iOrder );
  if( isset( $aBasket ) ){
    $iCount   = count( $aBasket );

    for( $i = 0; $i < $iCount; $i++ ){
      $iQuantity = $aBasket[$i][3];
      $iProduct  = $aBasket[$i][2];
      if( isset( $aStock[$iProduct] ) ){
        if( $iQuantity == $aStock[$iProduct] ){
          $aDisable[$iProduct]  = true;
          $aQuantity[$iProduct] = 0;
        }
        elseif( $iQuantity > $aStock[$iProduct] ){
          $aReturn[$iProduct] = $aStock[$iProduct];
        }
        else
          $aQuantity[$iProduct] = $iQuantity - $aStock[$iProduct];
      }
    } // end for

    if( isset( $aReturn ) )
      return $aReturn;
    else{
      /*
      * If quantity of product is 0 then it will be disabled to see for other customers 
      */
      if( isset( $aDisable ) ){
        $aFile  = file( DB_PRODUCTS );
        $rFile  = fopen( DB_PRODUCTS, 'w' );
        flock( $rFile, LOCK_EX );
        $iCount = count( $aFile );

        for( $i = 0; $i < $iCount; $i++ ){
          if( $i > 0 ){
            $aFile[$i]  = rtrim( $aFile[$i] );
            $aExp       = explode( '$', $aFile[$i] );
            if( isset( $aDisable[$aExp[0]] ) )
              $aFile[$i] = $aExp[0].'$'.$aExp[1].'$'.$aExp[2].'$'.$aExp[3].'$0$'.$aExp[5].'$'."\n";
            else
              $aFile[$i] .= "\n";
          }

          fwrite( $rFile, $aFile[$i] );
        } // end for

        flock( $rFile, LOCK_UN );
        fclose( $rFile );      
      }

      /*
      * Change product quantity 
      */
      if( isset( $aQuantity ) ){
        $aFile  = file( DB_PRODUCTS_STOCK );
        $rFile  = fopen( DB_PRODUCTS_STOCK, 'w' );
        flock( $rFile, LOCK_EX );
        $iCount = count( $aFile );

        for( $i = 0; $i < $iCount; $i++ ){
          if( $i > 0 ){
            $aFile[$i]  = rtrim( $aFile[$i] );
            $aExp       = explode( '$', $aFile[$i] );
            if( isset( $aQuantity[$aExp[0]] ) )
              $aFile[$i] = $aExp[0].'$'.$aQuantity[$aExp[0]].'$'."\n";
            else
              $aFile[$i] .= "\n";
          }

          fwrite( $rFile, $aFile[$i] );
        } // end for

        flock( $rFile, LOCK_UN );
        fclose( $rFile );      
      }
    }

  }
  else
    return null;
} // end function changeProductsStock

/**
* Return products stock if order is deleted
* @return void
* @param int  $iOrder
*/
function returnProductsStock( $iOrder ){
  $aBasket  = dbListBasket( $iOrder );
  if( isset( $aBasket ) ){
    $iCount   = count( $aBasket );

    for( $i = 0; $i < $iCount; $i++ ){
      $iQuantity = $aBasket[$i][3];
      $iProduct  = $aBasket[$i][2];
      $aQuantity[$iProduct] = $iQuantity;
    } // end for

    if( isset( $aQuantity ) ){
      $aFile  = file( DB_PRODUCTS_STOCK );
      $rFile  = fopen( DB_PRODUCTS_STOCK, 'w' );
      $iCount = count( $aFile );

      for( $i = 0; $i < $iCount; $i++ ){
        if( $i > 0 ){
          $aFile[$i]  = rtrim( $aFile[$i] );
          $aExp       = explode( '$', $aFile[$i] );
          if( isset( $aQuantity[$aExp[0]] ) )
            $aFile[$i] = $aExp[0].'$'.$aQuantity[$aExp[0]].'$'."\n";
          else
            $aFile[$i] .= "\n";
        }

        fwrite( $rFile, $aFile[$i] );
      } // end for

      fclose( $rFile );      
    }
  }
} // end function returnProductsStock

/**
* Return list of products limit
* @return string
* @param string $sFile
* @param array  $aData
*/
function listProductsOver( $sFile, $aData ){
  global $tpl, $aList;

  $aProducts  = throwProducts( );
  $content    = null;
  foreach( $aData as $aList['iProduct'] => $aList['iQuantity'] ){
    if( isset( $aProducts[$aList['iProduct']] ) ){
      $aList['sName'] = $aProducts[$aList['iProduct']];
      $content .= $tpl->tbHtml( $sFile, 'LIST_LIST' );
    }
  }
  if( isset( $content ) )
    return $tpl->tbHtml( $sFile, 'LIST_HEAD' ).$content.$tpl->tbHtml( $sFile, 'LIST_FOOT' );
} // end function listProductsOver
?>